# 人工智能操作的常用函数包
### 集合了常用的文件处理模块
#### 具体如下:
- 数据预处理
- - 图象数据集-视频提取图像
- - 图象数据集-自动分割
- - 图象数据集-图形自动标注

## 待完成
1. 拟合，分类 示例
2. 直方图，散点图，线图，饼图，热力图，箱线图 示例
3. 指定类别，自动标注
4. 交叉验证，混淆矩阵，ROC曲线，AUC值，PR曲线，F1值，准确率，召回率 示例
5. 文本数据预处理
6. charge
